@@ -256,7 +256,14 @@ class PyAVPlugin(PluginV3):
 
         if request.mode.io_mode == IOMode.read:
             try:
-                self._container = av.open(request.get_file())
+                if request._uri_type == 5:  # 5 is the value of URI_HTTP
+                    # pyav should read from HTTP by itself. This enables reading
+                    # HTTP-based streams like DASH. Note that solving streams
+                    # like this is temporary until the new request object gets
+                    # implemented.
+                    self._container = av.open(request.raw_uri)
+                else:
+                    self._container = av.open(request.get_file())
                 self._video_stream = self._container.streams.video[0]
                 self._decoder = self._container.decode(video=0)
             except av.AVError:
@@ -914,12 +921,14 @@ class PyAVPlugin(PluginV3):
 
         if index is ...:
             # useful flags defined on the container and/or video stream
+            duration = float(self._video_stream.duration * self._video_stream.time_base)
             metadata.update(
                 {
                     "video_format": self._video_stream.codec_context.pix_fmt,
                     "codec": self._video_stream.codec.name,
                     "long_codec": self._video_stream.codec.long_name,
                     "profile": self._video_stream.profile,
+                    "duration": duration,
                 }
             )
 
@@ -942,7 +951,7 @@ class PyAVPlugin(PluginV3):
         # side data
         metadata.update({key: value for key, value in desired_frame.side_data.items()})
 
-        return self._container.metadata
+        return metadata
 
     def _seek(self, index, *, constant_framerate: bool = True) -> None:
         """Seeks to the frame at the given index."""
