@@ -650,7 +650,7 @@ def test_read_stream(test_images):
 
     video_blob = Path(test_images / "cockatoo.mp4").read_bytes()
 
-    result = iio3.imread(video_blob, index=5, format_hint=".mp4")
+    result = iio3.imread(video_blob, index=5, extension=".mp4")
     expected = iio3.imread("imageio:cockatoo.mp4", index=5)
 
     assert np.allclose(result, expected)
