@@ -1,19 +1,17 @@
 """ Tests for imageio's pillow plugin
 """
 
+import io
+import os
 from pathlib import Path
 
-from imageio.core.request import Request
-import os
-import io
-import pytest
-import numpy as np
-from PIL import Image, ImageSequence  # type: ignore
-
 import imageio as iio
+import numpy as np
+import pytest
+from imageio.core.request import InitializationError, Request
 from imageio.core.v3_plugin_api import PluginV3
 from imageio.plugins.pillow import PillowPlugin
-from imageio.core.request import InitializationError
+from PIL import Image, ImageSequence  # type: ignore
 
 
 @pytest.mark.parametrize(
