@@ -55,7 +55,7 @@ def test_mp4_writing(tmp_path, test_images):
     )
 
     # libx264 writing is not deterministic and RGB -> YUV is lossy
-    # so I have good ideas how to do serious assertions on the file
+    # so I have no good ideas how to do serious assertions on the file
     assert mp4_bytes is not None
 
 
@@ -64,9 +64,12 @@ def test_metadata(test_images: Path):
         meta = plugin.metadata()
         assert meta["profile"] == "High 4:4:4 Predictive"
         assert meta["codec"] == "h264"
+        assert meta["encoder"] == "Lavf56.4.101"
+        assert meta["duration"] == 14
 
         meta = plugin.metadata(index=4)
-        assert meta["encoder"] == "Lavf56.4.101"
+        assert meta["time"] == 0.2
+        assert meta["key_frame"] is False
 
 
 def test_properties(test_images: Path):
@@ -371,3 +374,19 @@ def test_sequential_reading(test_images):
         actual_imgs = [first_read, second_read]
 
     np.allclose(actual_imgs, expected_imgs)
+
+
+def test_uri_reading(test_images):
+    uri = "https://dash.akamaized.net/dash264/TestCases/2c/qualcomm/1/MultiResMPEG2.mpd"
+
+    with av.open(uri) as container:
+        for idx, frame in enumerate(container.decode(video=0)):
+            if idx < 250:
+                continue
+
+            expected = frame.to_ndarray(format="rgb24")
+            break
+
+    actual = iio.imread(uri, plugin="pyav", index=250)
+
+    np.allclose(actual, expected)
